import request from '@/utils/request'

// 查询转接记录列表
export function listExternalContactTransferLog(query) {
  return request({
    url: '/qw/externalContactTransferLog/list',
    method: 'get',
    params: query
  })
}

export function syncTransferLog(id) {
  return request({
    url: '/qw/externalContactTransferLog/sync/' + id,
    method: 'get',

  })
}
// 查询转接记录详细
export function getExternalContactTransferLog(id) {
  return request({
    url: '/qw/externalContactTransferLog/' + id,
    method: 'get'
  })
}

// 新增转接记录
export function addExternalContactTransferLog(data) {
  return request({
    url: '/qw/externalContactTransferLog',
    method: 'post',
    data: data
  })
}

// 修改转接记录
export function updateExternalContactTransferLog(data) {
  return request({
    url: '/qw/externalContactTransferLog',
    method: 'put',
    data: data
  })
}

// 删除转接记录
export function delExternalContactTransferLog(id) {
  return request({
    url: '/qw/externalContactTransferLog/' + id,
    method: 'delete'
  })
}

// 导出转接记录
export function exportExternalContactTransferLog(query) {
  return request({
    url: '/qw/externalContactTransferLog/export',
    method: 'get',
    params: query
  })
}
