<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="企微账号" prop="qwUserId">
              <el-select v-model="queryParams.qwUserId" placeholder="企微账号" clearable size="small" @change="updateQwuser()">
                <el-option
                  v-for="dict in myQwUserList"
                  :key="dict.dictValue"
                  :label="dict.dictLabel + '('+dict.corpName+')'"
                  :value="dict.dictValue"
                />
              </el-select>
      </el-form-item>
      <el-form-item label="员工姓名" prop="companyUserNickName">
        <el-input
        style="width:220px"
          v-model="queryParams.companyUserNickName"
          placeholder="请输入员工姓名"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>



      <el-form-item label="状态" prop="status">
        <el-select v-model="queryParams.status" placeholder="请选择状态" clearable size="small">
          <el-option
            v-for="dict in statusOptions"
            :key="dict.dictValue"
            :label="dict.dictLabel"
            :value="dict.dictValue"
          />
        </el-select>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          :loading="exportLoading"
          @click="handleExport"
          v-hasPermi="['qw:externalContactTransferLog:export']"
        >导出</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-download"
          size="mini"
          :loading="exportLoading"
          @click="snyc"
          v-hasPermi="['qw:externalContactTransferLog:snyc']"
        >同步</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="externalContactTransferLogList" @selection-change="handleSelectionChange" border>
      <el-table-column type="selection" width="55" align="center" />
<!--      <el-table-column label="账号" align="center" prop="id" />-->
      <el-table-column label="原员工" align="center" prop="handoverQwUserName" />
      <el-table-column label="客户名称" align="center" prop="name" />
      <el-table-column label="接替员工" align="center" prop="companyUserNickName" />
      <el-table-column label="员工部门" align="center" prop="deptName" />
      <el-table-column label="转接时间" align="center" prop="createTime" />
      <el-table-column label="状态" align="center" prop="status">
        <template slot-scope="scope">
          <dict-tag :options="statusOptions" :value="scope.row.status"/>
        </template>
      </el-table-column>

    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改转接记录对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="企业id" prop="corpId">
          <el-input v-model="form.corpId" placeholder="请输入企业id" />
        </el-form-item>
        <el-form-item label="公司id" prop="companyId">
          <el-input v-model="form.companyId" placeholder="请输入公司id" />
        </el-form-item>
        <el-form-item label="员工id" prop="companyUserId">
          <el-input v-model="form.companyUserId" placeholder="请输入员工id" />
        </el-form-item>
        <el-form-item label="企微外部联系人id" prop="externalUserId">
          <el-input v-model="form.externalUserId" placeholder="请输入企微外部联系人id" />
        </el-form-item>
        <el-form-item label="客户id" prop="customerId">
          <el-input v-model="form.customerId" placeholder="请输入客户id" />
        </el-form-item>
        <el-form-item label="外部联系人id" prop="externalContactId">
          <el-input v-model="form.externalContactId" placeholder="请输入外部联系人id" />
        </el-form-item>
        <el-form-item label="状态" prop="status">
          <el-select v-model="form.status" placeholder="请选择状态">
            <el-option
              v-for="dict in statusOptions"
              :key="dict.dictValue"
              :label="dict.dictLabel"
              :value="dict.dictValue"
            ></el-option>
          </el-select>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { syncTransferLog,listExternalContactTransferLog, getExternalContactTransferLog, delExternalContactTransferLog, addExternalContactTransferLog, updateExternalContactTransferLog, exportExternalContactTransferLog } from "@/api/qw/externalContactTransferLog";
import { getMyQwUserList,getMyQwCompanyList } from "@/api/qw/user";
export default {
  name: "ExternalContactTransferLog",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 导出遮罩层
      exportLoading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 转接记录表格数据
      externalContactTransferLogList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      myQwUserList:[],
      // 状态字典
      statusOptions: [],
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        corpId: null,
        companyId: null,
        companyUserId: null,
        externalUserId: null,
        customerId: null,
        externalContactId: null,
        status: null,
        companyUserNickName:null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
      }
    };
  },
  created() {
    getMyQwUserList().then(response => {
		this.myQwUserList = response.data;
		if(this.myQwUserList!=null){
		  this.queryParams.qwUserId=this.myQwUserList[0].dictValue
		  this.getList();
		}
    });
    this.getDicts("sys_qw_transfer_status").then(response => {
      this.statusOptions = response.data;
    });
  },
  methods: {
    updateQwuser(){
           this.getList();
     },
    /** 查询转接记录列表 */
    getList() {
      this.loading = true;
      listExternalContactTransferLog(this.queryParams).then(response => {
        this.externalContactTransferLogList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    snyc(){
      syncTransferLog(this.queryParams.corpId).then(response => {
        this.msgSuccess("同步成功");
        this.getList();
      });
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        corpId: null,
        companyId: null,
        companyUserId: null,
        externalUserId: null,
        customerId: null,
        externalContactId: null,
        status: null,
        createTime: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.queryParams.qwUserId=this.myQwUserList[0].dictValue
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加转接记录";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getExternalContactTransferLog(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改转接记录";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateExternalContactTransferLog(this.form).then(response => {
              this.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addExternalContactTransferLog(this.form).then(response => {
              this.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$confirm('是否确认删除转接记录编号为"' + ids + '"的数据项?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(function() {
          return delExternalContactTransferLog(ids);
        }).then(() => {
          this.getList();
          this.msgSuccess("删除成功");
        }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams;
      this.$confirm('是否确认导出所有转接记录数据项?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(() => {
          this.exportLoading = true;
          return exportExternalContactTransferLog(queryParams);
        }).then(response => {
          this.download(response.msg);
          this.exportLoading = false;
        }).catch(() => {});
    }
  }
};
</script>
